@@ -1,10 +1,13 @@
 '''
 Author: BDFD
 Date: 2021-10-27 18:42:50
-LastEditTime: 2022-02-24 14:32:30
+LastEditTime: 2022-03-01 17:34:14
 LastEditors: BDFD
 Description: In User Settings Edit
 FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\__init__.py
 '''
 
 from WES_Calculation.templateproj import add_one
+from WES_Calculation.templateproj import add_two
+from WES_Calculation.gumbel import gumbel
+from WES_Calculation.greenampt import gumbeltest
